
#ifndef KPIMIDENTITIES_EXPORT_H
#define KPIMIDENTITIES_EXPORT_H

#ifdef KPIMIDENTITIES_STATIC_DEFINE
#  define KPIMIDENTITIES_EXPORT
#  define KPIMIDENTITIES_NO_EXPORT
#else
#  ifndef KPIMIDENTITIES_EXPORT
#    ifdef kpimidentities_EXPORTS
        /* We are building this library */
#      define KPIMIDENTITIES_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KPIMIDENTITIES_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KPIMIDENTITIES_NO_EXPORT
#    define KPIMIDENTITIES_NO_EXPORT 
#  endif
#endif

#ifndef KPIMIDENTITIES_DEPRECATED
#  define KPIMIDENTITIES_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPIMIDENTITIES_DEPRECATED_EXPORT
#  define KPIMIDENTITIES_DEPRECATED_EXPORT KPIMIDENTITIES_EXPORT KPIMIDENTITIES_DEPRECATED
#endif

#ifndef KPIMIDENTITIES_DEPRECATED_NO_EXPORT
#  define KPIMIDENTITIES_DEPRECATED_NO_EXPORT KPIMIDENTITIES_NO_EXPORT KPIMIDENTITIES_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KPIMIDENTITIES_NO_DEPRECATED
#endif

#endif
