
#ifndef MICROBLOG_EXPORT_H
#define MICROBLOG_EXPORT_H

#ifdef MICROBLOG_STATIC_DEFINE
#  define MICROBLOG_EXPORT
#  define MICROBLOG_NO_EXPORT
#else
#  ifndef MICROBLOG_EXPORT
#    ifdef microblog_EXPORTS
        /* We are building this library */
#      define MICROBLOG_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define MICROBLOG_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef MICROBLOG_NO_EXPORT
#    define MICROBLOG_NO_EXPORT 
#  endif
#endif

#ifndef MICROBLOG_DEPRECATED
#  define MICROBLOG_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MICROBLOG_DEPRECATED_EXPORT
#  define MICROBLOG_DEPRECATED_EXPORT MICROBLOG_EXPORT MICROBLOG_DEPRECATED
#endif

#ifndef MICROBLOG_DEPRECATED_NO_EXPORT
#  define MICROBLOG_DEPRECATED_NO_EXPORT MICROBLOG_NO_EXPORT MICROBLOG_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define MICROBLOG_NO_DEPRECATED
#endif

#endif
