
#ifndef KRESOURCES_EXPORT_H
#define KRESOURCES_EXPORT_H

#ifdef KRESOURCES_STATIC_DEFINE
#  define KRESOURCES_EXPORT
#  define KRESOURCES_NO_EXPORT
#else
#  ifndef KRESOURCES_EXPORT
#    ifdef kresources_EXPORTS
        /* We are building this library */
#      define KRESOURCES_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KRESOURCES_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KRESOURCES_NO_EXPORT
#    define KRESOURCES_NO_EXPORT 
#  endif
#endif

#ifndef KRESOURCES_DEPRECATED
#  define KRESOURCES_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KRESOURCES_DEPRECATED_EXPORT
#  define KRESOURCES_DEPRECATED_EXPORT KRESOURCES_EXPORT KRESOURCES_DEPRECATED
#endif

#ifndef KRESOURCES_DEPRECATED_NO_EXPORT
#  define KRESOURCES_DEPRECATED_NO_EXPORT KRESOURCES_NO_EXPORT KRESOURCES_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KRESOURCES_NO_DEPRECATED
#endif

#endif
