
#ifndef KTNEF_EXPORT_H
#define KTNEF_EXPORT_H

#ifdef KTNEF_STATIC_DEFINE
#  define KTNEF_EXPORT
#  define KTNEF_NO_EXPORT
#else
#  ifndef KTNEF_EXPORT
#    ifdef ktnef_EXPORTS
        /* We are building this library */
#      define KTNEF_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KTNEF_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KTNEF_NO_EXPORT
#    define KTNEF_NO_EXPORT 
#  endif
#endif

#ifndef KTNEF_DEPRECATED
#  define KTNEF_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KTNEF_DEPRECATED_EXPORT
#  define KTNEF_DEPRECATED_EXPORT KTNEF_EXPORT KTNEF_DEPRECATED
#endif

#ifndef KTNEF_DEPRECATED_NO_EXPORT
#  define KTNEF_DEPRECATED_NO_EXPORT KTNEF_NO_EXPORT KTNEF_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KTNEF_NO_DEPRECATED
#endif

#endif
