
#ifndef MAILTRANSPORT_EXPORT_H
#define MAILTRANSPORT_EXPORT_H

#ifdef MAILTRANSPORT_STATIC_DEFINE
#  define MAILTRANSPORT_EXPORT
#  define MAILTRANSPORT_NO_EXPORT
#else
#  ifndef MAILTRANSPORT_EXPORT
#    ifdef mailtransport_EXPORTS
        /* We are building this library */
#      define MAILTRANSPORT_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define MAILTRANSPORT_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef MAILTRANSPORT_NO_EXPORT
#    define MAILTRANSPORT_NO_EXPORT 
#  endif
#endif

#ifndef MAILTRANSPORT_DEPRECATED
#  define MAILTRANSPORT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MAILTRANSPORT_DEPRECATED_EXPORT
#  define MAILTRANSPORT_DEPRECATED_EXPORT MAILTRANSPORT_EXPORT MAILTRANSPORT_DEPRECATED
#endif

#ifndef MAILTRANSPORT_DEPRECATED_NO_EXPORT
#  define MAILTRANSPORT_DEPRECATED_NO_EXPORT MAILTRANSPORT_NO_EXPORT MAILTRANSPORT_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define MAILTRANSPORT_NO_DEPRECATED
#endif

#endif
