
#ifndef AKONADI_CALENDAR_EXPORT_H
#define AKONADI_CALENDAR_EXPORT_H

#ifdef AKONADI_CALENDAR_STATIC_DEFINE
#  define AKONADI_CALENDAR_EXPORT
#  define AKONADI_CALENDAR_NO_EXPORT
#else
#  ifndef AKONADI_CALENDAR_EXPORT
#    ifdef akonadi_calendar
        /* We are building this library */
#      define AKONADI_CALENDAR_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define AKONADI_CALENDAR_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef AKONADI_CALENDAR_NO_EXPORT
#    define AKONADI_CALENDAR_NO_EXPORT 
#  endif
#endif

#ifndef AKONADI_CALENDAR_DEPRECATED
#  define AKONADI_CALENDAR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_CALENDAR_DEPRECATED_EXPORT
#  define AKONADI_CALENDAR_DEPRECATED_EXPORT AKONADI_CALENDAR_EXPORT AKONADI_CALENDAR_DEPRECATED
#endif

#ifndef AKONADI_CALENDAR_DEPRECATED_NO_EXPORT
#  define AKONADI_CALENDAR_DEPRECATED_NO_EXPORT AKONADI_CALENDAR_NO_EXPORT AKONADI_CALENDAR_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define AKONADI_CALENDAR_NO_DEPRECATED
#endif

#endif
