
#ifndef KABC_EXPORT_H
#define KABC_EXPORT_H

#ifdef KABC_STATIC_DEFINE
#  define KABC_EXPORT
#  define KABC_NO_EXPORT
#else
#  ifndef KABC_EXPORT
#    ifdef kabc_EXPORTS
        /* We are building this library */
#      define KABC_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KABC_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KABC_NO_EXPORT
#    define KABC_NO_EXPORT 
#  endif
#endif

#ifndef KABC_DEPRECATED
#  define KABC_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KABC_DEPRECATED_EXPORT
#  define KABC_DEPRECATED_EXPORT KABC_EXPORT KABC_DEPRECATED
#endif

#ifndef KABC_DEPRECATED_NO_EXPORT
#  define KABC_DEPRECATED_NO_EXPORT KABC_NO_EXPORT KABC_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KABC_NO_DEPRECATED
#endif

#endif
