
#ifndef LIBAKONADISOCIALUTILS_EXPORT_H
#define LIBAKONADISOCIALUTILS_EXPORT_H

#ifdef LIBAKONADISOCIALUTILS_STATIC_DEFINE
#  define LIBAKONADISOCIALUTILS_EXPORT
#  define LIBAKONADISOCIALUTILS_NO_EXPORT
#else
#  ifndef LIBAKONADISOCIALUTILS_EXPORT
#    ifdef akonadi_socialutils
        /* We are building this library */
#      define LIBAKONADISOCIALUTILS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define LIBAKONADISOCIALUTILS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef LIBAKONADISOCIALUTILS_NO_EXPORT
#    define LIBAKONADISOCIALUTILS_NO_EXPORT 
#  endif
#endif

#ifndef LIBAKONADISOCIALUTILS_DEPRECATED
#  define LIBAKONADISOCIALUTILS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBAKONADISOCIALUTILS_DEPRECATED_EXPORT
#  define LIBAKONADISOCIALUTILS_DEPRECATED_EXPORT LIBAKONADISOCIALUTILS_EXPORT LIBAKONADISOCIALUTILS_DEPRECATED
#endif

#ifndef LIBAKONADISOCIALUTILS_DEPRECATED_NO_EXPORT
#  define LIBAKONADISOCIALUTILS_DEPRECATED_NO_EXPORT LIBAKONADISOCIALUTILS_NO_EXPORT LIBAKONADISOCIALUTILS_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define LIBAKONADISOCIALUTILS_NO_DEPRECATED
#endif

#endif
