
#ifndef KCALCORE_EXPORT_H
#define KCALCORE_EXPORT_H

#ifdef KCALCORE_STATIC_DEFINE
#  define KCALCORE_EXPORT
#  define KCALCORE_NO_EXPORT
#else
#  ifndef KCALCORE_EXPORT
#    ifdef kcalcore_EXPORTS
        /* We are building this library */
#      define KCALCORE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KCALCORE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KCALCORE_NO_EXPORT
#    define KCALCORE_NO_EXPORT 
#  endif
#endif

#ifndef KCALCORE_DEPRECATED
#  define KCALCORE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCALCORE_DEPRECATED_EXPORT
#  define KCALCORE_DEPRECATED_EXPORT KCALCORE_EXPORT KCALCORE_DEPRECATED
#endif

#ifndef KCALCORE_DEPRECATED_NO_EXPORT
#  define KCALCORE_DEPRECATED_NO_EXPORT KCALCORE_NO_EXPORT KCALCORE_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KCALCORE_NO_DEPRECATED
#endif

#endif
