
#ifndef KCAL_EXPORT_H
#define KCAL_EXPORT_H

#ifdef KCAL_STATIC_DEFINE
#  define KCAL_EXPORT
#  define KCAL_NO_EXPORT
#else
#  ifndef KCAL_EXPORT
#    ifdef kcal_EXPORTS
        /* We are building this library */
#      define KCAL_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KCAL_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KCAL_NO_EXPORT
#    define KCAL_NO_EXPORT 
#  endif
#endif

#ifndef KCAL_DEPRECATED
#  define KCAL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCAL_DEPRECATED_EXPORT
#  define KCAL_DEPRECATED_EXPORT KCAL_EXPORT KCAL_DEPRECATED
#endif

#ifndef KCAL_DEPRECATED_NO_EXPORT
#  define KCAL_DEPRECATED_NO_EXPORT KCAL_NO_EXPORT KCAL_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KCAL_NO_DEPRECATED
#endif

#endif
