
#ifndef AKONADI_KMIME_EXPORT_H
#define AKONADI_KMIME_EXPORT_H

#ifdef AKONADI_KMIME_STATIC_DEFINE
#  define AKONADI_KMIME_EXPORT
#  define AKONADI_KMIME_NO_EXPORT
#else
#  ifndef AKONADI_KMIME_EXPORT
#    ifdef akonadi_kmime
        /* We are building this library */
#      define AKONADI_KMIME_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define AKONADI_KMIME_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef AKONADI_KMIME_NO_EXPORT
#    define AKONADI_KMIME_NO_EXPORT 
#  endif
#endif

#ifndef AKONADI_KMIME_DEPRECATED
#  define AKONADI_KMIME_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef AKONADI_KMIME_DEPRECATED_EXPORT
#  define AKONADI_KMIME_DEPRECATED_EXPORT AKONADI_KMIME_EXPORT AKONADI_KMIME_DEPRECATED
#endif

#ifndef AKONADI_KMIME_DEPRECATED_NO_EXPORT
#  define AKONADI_KMIME_DEPRECATED_NO_EXPORT AKONADI_KMIME_NO_EXPORT AKONADI_KMIME_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define AKONADI_KMIME_NO_DEPRECATED
#endif

#endif
