
#ifndef KPIMTEXTEDIT_EXPORT_H
#define KPIMTEXTEDIT_EXPORT_H

#ifdef KPIMTEXTEDIT_STATIC_DEFINE
#  define KPIMTEXTEDIT_EXPORT
#  define KPIMTEXTEDIT_NO_EXPORT
#else
#  ifndef KPIMTEXTEDIT_EXPORT
#    ifdef kpimtextedit_EXPORTS
        /* We are building this library */
#      define KPIMTEXTEDIT_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KPIMTEXTEDIT_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KPIMTEXTEDIT_NO_EXPORT
#    define KPIMTEXTEDIT_NO_EXPORT 
#  endif
#endif

#ifndef KPIMTEXTEDIT_DEPRECATED
#  define KPIMTEXTEDIT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPIMTEXTEDIT_DEPRECATED_EXPORT
#  define KPIMTEXTEDIT_DEPRECATED_EXPORT KPIMTEXTEDIT_EXPORT KPIMTEXTEDIT_DEPRECATED
#endif

#ifndef KPIMTEXTEDIT_DEPRECATED_NO_EXPORT
#  define KPIMTEXTEDIT_DEPRECATED_NO_EXPORT KPIMTEXTEDIT_NO_EXPORT KPIMTEXTEDIT_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KPIMTEXTEDIT_NO_DEPRECATED
#endif

#endif
